# StorageOS Helm Chart
```bash
# install
helm install /etc/kubernetes/helm/storageos \
--name=storageos \
--namespace=storageos \
-f /etc/kubernetes/helm/storageos/values-overrides.yaml

# 2. Uninstall Gitlab
helm del --purge storageos
```

## overrides
```bash
cat /etc/kubernetes/helm/storageos/values-overrides.yaml
```

```yaml
image:
  repository: registry.cn-qingdao.aliyuncs.com/wod/storageos-node
  tag: 1.0.0-rc5
  pullPolicy: IfNotPresent

initContainer:
  repository: registry.cn-qingdao.aliyuncs.com/wod/storageos-init
  tag: 0.1
  pullPolicy: IfNotPresent

csiDriverRegistrar:
  repository: registry.cn-qingdao.aliyuncs.com/wod/k8scsi-driver-registrar
  tag: v0.2.0
  pullPolicy: IfNotPresent

csiExternalProvisioner:
  repository: registry.cn-qingdao.aliyuncs.com/wod/k8scsi-csi-provisioner
  tag: v0.3.0
  pullPolicy: Always

csiExternalAttacher:
  repository: registry.cn-qingdao.aliyuncs.com/wod/k8scsi-csi-attacher
  tag: v0.3.0
  pullPolicy: Always

rbacEnabled: true

cluster:
  # master node ip
  join: 172.16.1.1
  sharedDir: /data/storageos
  kv_address: 172.16.1.1:2379
  kv_backend: etcd

storageclass:
  name: storageos
  pool: default
  fsType: ext4
api:
  secretName: storageos-api
  secretNamespace: default
  address: storageos:5705
  username: admin
  password: "abcd2018"
namespace: storageos

ingress:
  enabled: true
  hosts:
  - name: storageos.wodcloud.local

csi:
  enable: true
```

## images

由于rc-5版本免费试用的额度为500GB不够用，所以部署rc-4版本

```bash
docker pull storageos/node:1.0.0-rc4 && \
docker tag storageos/node:1.0.0-rc4 registry-vpc.cn-qingdao.aliyuncs.com/wod/storageos-node:1.0.0-rc4 && \
docker push registry-vpc.cn-qingdao.aliyuncs.com/wod/storageos-node:1.0.0-rc4

docker pull storageos/init:0.1 && \
docker tag storageos/init:0.1 registry-vpc.cn-qingdao.aliyuncs.com/wod/storageos-init:0.1 && \
docker push registry-vpc.cn-qingdao.aliyuncs.com/wod/storageos-init:0.1

docker pull quay.io/k8scsi/driver-registrar:v0.2.0 && \
docker tag quay.io/k8scsi/driver-registrar:v0.2.0 registry-vpc.cn-qingdao.aliyuncs.com/wod/k8scsi-driver-registrar:v0.2.0 && \
docker push registry-vpc.cn-qingdao.aliyuncs.com/wod/k8scsi-driver-registrar:v0.2.0

docker pull quay.io/k8scsi/csi-provisioner:v0.3.0 && \
docker tag quay.io/k8scsi/csi-provisioner:v0.3.0 registry-vpc.cn-qingdao.aliyuncs.com/wod/k8scsi-csi-provisioner:v0.3.0 && \
docker push registry-vpc.cn-qingdao.aliyuncs.com/wod/k8scsi-csi-provisioner:v0.3.0

docker pull quay.io/k8scsi/csi-attacher:v0.3.0 && \
docker tag quay.io/k8scsi/csi-attacher:v0.3.0 registry-vpc.cn-qingdao.aliyuncs.com/wod/k8scsi-csi-attacher:v0.3.0 && \
docker push registry-vpc.cn-qingdao.aliyuncs.com/wod/k8scsi-csi-attacher:v0.3.0
```